"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function transform(name, lang) {
    const rules = DATA[lang];
    const MIN_WORD_LENGTH = 2;
    if (rules) {
        let names = name.split(/\s+/g).map(word => ({ word, transform: word.length > MIN_WORD_LENGTH }));
        switch (lang) {
            case 'ro':
                names.forEach((item, i) => item.transform = item.transform && i == 0);
                break;
        }
        const rootNames = names.map(item => {
            if (item.transform) {
                const w = internalTransform(rules, item.word);
                if (w.length >= MIN_WORD_LENGTH) {
                    return w;
                }
            }
            return item.word;
        });
        return rootNames.join(' ');
    }
    return name;
}
exports.default = transform;
function internalTransform(rules, name) {
    for (let rule of rules) {
        let root = name.replace(rule.reg, rule.replace);
        if (root !== name) {
            return root;
        }
    }
    return name;
}
const DATA = {
    ro: [
        {
            reg: /(-ului|-lui|ei|a|[`']s)$/i,
            replace: '',
        },
        {
            reg: /(lui)$/i,
            replace: 'l',
        },
    ],
    ru: [
        {
            reg: /(йские|йском|йской|йский|йская|йскую|ские|ском|ской|ский|ская|скую|ого|ым|ом|ой|ая|а|у|е|я|и|ю|[`']s)$/i,
            replace: '',
        },
    ],
};
